==> GotoBLAS-1.00.tar.gz: GotoBLAS/level2/syr/syr_k.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

int CNAME(long m, FLOAT alpha, FLOAT *x,
		      long incx, FLOAT *a, long lda, FLOAT *buffer){

  long i, is;
  long min_i;
  FLOAT *p;

  for(is = 0; is < m; is += SYR_P1){
    min_i = MIN(SYR_P1, m - is);
      
    p = x + is;

    if (incx != 1){
      for (i = 0; i < min_i; i++) buffer[i] = x[(is + i) * incx];
      p = buffer;
    }

#ifndef LOWER
    for (i = 0; i < min_i; i++){
      AXPY_K(i + 1, 0, 0, alpha * p[i], 
	    p, 1, &a[is + (i + is) * lda], 1, NULL, 0);
    }
    
    if (m - is > SYR_P1){
      GER_K(min_i, m - is - SYR_P1, 0, alpha,
	  p                         , 1,
	  x +       (is + SYR_P1) * incx, incx, 
	  a + is  + (is + SYR_P1) * lda,  lda, buffer + SUB_BUFFER_OFFSET);
    }
    
#else
    if (is > 0){
      GER_K(min_i, is, 0, alpha, p, 1, x, incx, a + is, lda, buffer + SUB_BUFFER_OFFSET);
    }
    
    for (i = 0; i < min_i; i++){
      AXPY_K(min_i - i, 0, 0, alpha * *(p + i), 
	    p + i, 1,
	    &a[(i + is) + (i + is) * lda], 1, NULL, 0);
    }
#endif
  }

  return 0;
}

==> GotoBLAS-1.10.tar.gz: GotoBLAS/level2/syr/syr_k.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include "common.h"

int CNAME(long m, FLOAT alpha_r, 
	  FLOAT *x, long incx, FLOAT *a, long lda, FLOAT *buffer){

  long i;
  FLOAT *X;

  X = x;

  if (incx != 1) {
    COPY_K(m, x, incx, buffer, 1);
    X = buffer;
  }

  for (i = 0; i < m; i++){
#ifndef LOWER
    if (X[i] != ZERO) {
      AXPY_K(i + 1, 0, 0, alpha_r * X[i], X,     1, a, 1, NULL, 0);
    }
    a += lda;
#else
    if (X[i] != ZERO) {
      AXPY_K(m - i, 0, 0, alpha_r * X[i], X + i, 1, a, 1, NULL, 0);
    }
    a += 1 + lda;
#endif
    }

  return 0;
}
